"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  LOG_LEVELS: true
};
exports.default = exports.LOG_LEVELS = void 0;

var _chalk = _interopRequireDefault(require("chalk"));

var _invariants = require("./invariants");

Object.keys(_invariants).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === _invariants[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _invariants[key];
    }
  });
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const LOG_LEVELS = {
  DEBUG: 0,
  INFO: 1,
  WARNING: 2,
  ERROR: 3
};
exports.LOG_LEVELS = LOG_LEVELS;
const levelToColour = {
  [LOG_LEVELS.DEBUG]: _chalk.default.magenta,
  [LOG_LEVELS.INFO]: _chalk.default.reset,
  [LOG_LEVELS.WARNING]: _chalk.default.yellow,
  [LOG_LEVELS.ERROR]: _chalk.default.red
};
const loggerOpts = {
  dryRun: false
};

const getCurrentLogLevel = () => {
  const envLogLevel = Number(process.env.MONODEPLOY_LOG_LEVEL);
  return isNaN(envLogLevel) ? LOG_LEVELS.WARNING : envLogLevel;
};

const createLogger = level => (...args) => {
  if (getCurrentLogLevel() > level) return;
  const date = new Date();
  const timestamp = `[${String(date.getHours()).padStart(2, '0')}:${String(date.getMinutes()).padStart(2, '0')}:${String(date.getSeconds()).padStart(2, '0')}.${String(date.getMilliseconds()).padStart(3, '0')}]`;
  const colour = levelToColour[level];
  const line = [_chalk.default.yellow(timestamp)];

  if (loggerOpts.dryRun && level === LOG_LEVELS.INFO) {
    line.push(_chalk.default.grey('[Dry Run]'));
  }

  line.push(colour(args[0]));
  const logFn = level >= LOG_LEVELS.WARNING ? console.error : console.log;
  logFn(line.join(' '));

  if (args.length > 1) {
    for (const arg of args.slice(1)) {
      logFn(colour(arg));
    }
  }
};

const setDryRun = value => {
  loggerOpts.dryRun = value;
};

const logger = {
  debug: createLogger(LOG_LEVELS.DEBUG),
  info: createLogger(LOG_LEVELS.INFO),
  warning: createLogger(LOG_LEVELS.WARNING),
  error: createLogger(LOG_LEVELS.ERROR),
  setDryRun
};
var _default = logger;
exports.default = _default;