"use strict";

var _ = _interopRequireWildcard(require("."));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

describe('Logging', () => {
  const origLogLevel = process.env.MONODEPLOY_LOG_LEVEL;
  beforeAll(() => {
    jest.spyOn(console, 'log').mockImplementation();
    jest.spyOn(console, 'error').mockImplementation();
  });
  afterEach(() => {
    jest.resetAllMocks();

    if (origLogLevel === undefined) {
      delete process.env.MONODEPLOY_LOG_LEVEL;
    } else {
      process.env.MONODEPLOY_LOG_LEVEL = origLogLevel;
    }

    _.default.setDryRun(false);
  });
  it('respects log level', () => {
    process.env.MONODEPLOY_LOG_LEVEL = _.LOG_LEVELS.DEBUG;

    _.default.debug('m1');

    _.default.info('m2');

    _.default.warning('m3');

    _.default.error('m4');

    expect(console.log).toBeCalledWith(expect.stringContaining('m1'));
    expect(console.log).toBeCalledWith(expect.stringContaining('m2'));
    expect(console.error).toBeCalledWith(expect.stringContaining('m3'));
    expect(console.error).toBeCalledWith(expect.stringContaining('m4'));
    jest.resetAllMocks();
    process.env.MONODEPLOY_LOG_LEVEL = _.LOG_LEVELS.INFO;

    _.default.debug('m1');

    _.default.info('m2');

    _.default.warning('m3');

    _.default.error('m4');

    expect(console.log).not.toBeCalledWith(expect.stringContaining('m1'));
    expect(console.log).toBeCalledWith(expect.stringContaining('m2'));
    expect(console.error).toBeCalledWith(expect.stringContaining('m3'));
    expect(console.error).toBeCalledWith(expect.stringContaining('m4'));
    jest.resetAllMocks();
    process.env.MONODEPLOY_LOG_LEVEL = _.LOG_LEVELS.WARNING;

    _.default.debug('m1');

    _.default.info('m2');

    _.default.warning('m3');

    _.default.error('m4');

    expect(console.log).not.toBeCalledWith(expect.stringContaining('m1'));
    expect(console.log).not.toBeCalledWith(expect.stringContaining('m2'));
    expect(console.error).toBeCalledWith(expect.stringContaining('m3'));
    expect(console.error).toBeCalledWith(expect.stringContaining('m4'));
    jest.resetAllMocks();
    process.env.MONODEPLOY_LOG_LEVEL = _.LOG_LEVELS.ERROR;

    _.default.debug('m1');

    _.default.info('m2');

    _.default.warning('m3');

    _.default.error('m4');

    expect(console.log).not.toBeCalledWith(expect.stringContaining('m1'));
    expect(console.log).not.toBeCalledWith(expect.stringContaining('m2'));
    expect(console.error).not.toBeCalledWith(expect.stringContaining('m3'));
    expect(console.error).toBeCalledWith(expect.stringContaining('m4'));
  });
  it('prints dry run prefix when dry run configured', () => {
    process.env.MONODEPLOY_LOG_LEVEL = _.LOG_LEVELS.INFO;

    _.default.setDryRun(true);

    _.default.info('m1');

    expect(console.log).toBeCalledWith(expect.stringContaining('m1'));
    expect(console.log).toBeCalledWith(expect.stringContaining('[Dry Run]'));
    jest.resetAllMocks();

    _.default.setDryRun(false);

    _.default.info('m1');

    expect(console.log).toBeCalledWith(expect.stringContaining('m1'));
    expect(console.log).not.toBeCalledWith(expect.stringContaining('[Dry Run]'));
  });
  it('prints all args', () => {
    process.env.MONODEPLOY_LOG_LEVEL = _.LOG_LEVELS.INFO;

    _.default.info('m1', 'm2', 'm3');

    expect(console.log).toBeCalledWith(expect.stringContaining('m1'));
    expect(console.log).toBeCalledWith(expect.stringContaining('m2'));
    expect(console.log).toBeCalledWith(expect.stringContaining('m3'));
  });
  it('defaults to log level warning', () => {
    delete process.env.MONODEPLOY_LOG_LEVEL;

    _.default.debug('m1');

    _.default.info('m2');

    _.default.warning('m3');

    _.default.error('m4');

    expect(console.log).not.toBeCalledWith(expect.stringContaining('m1'));
    expect(console.log).not.toBeCalledWith(expect.stringContaining('m2'));
    expect(console.error).toBeCalledWith(expect.stringContaining('m3'));
    expect(console.error).toBeCalledWith(expect.stringContaining('m4'));
  });
  it('falls back to log level warning', () => {
    process.env.MONODEPLOY_LOG_LEVEL = 'not-a-number';

    _.default.debug('m1');

    _.default.info('m2');

    _.default.warning('m3');

    _.default.error('m4');

    expect(console.log).not.toBeCalledWith(expect.stringContaining('m1'));
    expect(console.log).not.toBeCalledWith(expect.stringContaining('m2'));
    expect(console.error).toBeCalledWith(expect.stringContaining('m3'));
    expect(console.error).toBeCalledWith(expect.stringContaining('m4'));
  });
});